@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0608';
+our $VERSION = '0.0609';
 
 use Moo;
 use strictures 2;
@@ -44,7 +44,8 @@ has chord_map => (
 );
 sub _build_chord_map {
     my ($self) = @_;
-    my %modes = (
+    my %scale = (
+        chromatic  => [ ('m') x 12 ],
         major      => [ '',    'm',   'm',   '',    '',    'm',   'dim' ],
         ionian     => [ '',    'm',   'm',   '',    '',    'm',   'dim' ],
         dorian     => [ 'm',   'm',   '',    '',    'm',   'dim', ''    ],
@@ -55,7 +56,7 @@ sub _build_chord_map {
         aeolian    => [ 'm',   'dim', '',    'm',   'm',   '',    ''    ],
         locrian    => [ 'dim', '',    'm',   'm',   '',    '',    'm'   ],
     );
-    return $modes{ $self->scale_name };
+    return $scale{ $self->scale_name };
 }
 
 
@@ -366,7 +367,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0608
+version 0.0609
 
 =head1 SYNOPSIS
 
@@ -450,6 +451,22 @@ Default: C<[ '', 'm', 'm', '', '', 'm', 'dim' ]> (major scale)
 
 Here C<''> refers to the major chord and C<'m'> means minor.
 
+Here are the known chord mappings:
+
+  chromatic  => [ ('m') x 12 ],
+  major      => [ '',    'm',   'm',   '',    '',    'm',   'dim' ],
+  ionian     => [ '',    'm',   'm',   '',    '',    'm',   'dim' ],
+  dorian     => [ 'm',   'm',   '',    '',    'm',   'dim', ''    ],
+  phrygian   => [ 'm',   '',    '',    'm',   'dim', '',    'm'   ],
+  lydian     => [ '',    '',    'm',   'dim', '',    'm',   'm'   ],
+  mixolydian => [ '',    'm',   'dim', '',    'm',   'm',   ''    ],
+  minor      => [ 'm',   'dim', '',    'm',   'm',   '',    ''    ],
+  aeolian    => [ 'm',   'dim', '',    'm',   'm',   '',    ''    ],
+  locrian    => [ 'dim', '',    'm',   'm',   '',    '',    'm'   ],
+
+If B<chord_map>  is not defined and a known B<scale_name> is given to
+the constructor, the corresponding B<chord_map> above, will be used.
+
 Alternative example:
 
   [ 'M7', 'm7', 'm7', 'M7', '7', 'm7', 'dim7' ]
